int create_frontend(struct Camera*);

static gint configure_event (GtkWidget*, GdkEventConfigure*, struct Camera*);
static gint expose_event (GtkWidget*, GdkEventExpose*, struct Camera*);
void freeze(GtkWidget*, struct Camera*);

void setbrightness(GtkAdjustment*, struct Camera*);
void setwhite(GtkAdjustment*, struct Camera*);
void setcontrast(GtkAdjustment*, struct Camera*);
void sethue(GtkAdjustment*, struct Camera*);
void setcolor(GtkAdjustment*, struct Camera*);
void setsizefull(GtkWidget*, struct Camera*);
void setsizehalf(GtkWidget*, struct Camera*);
void setsizequarter(GtkWidget*, struct Camera*);
void setdepth4(GtkWidget*, struct Camera*);
void setdepth6(GtkWidget*, struct Camera*);

void clearimg(struct Camera*);
void update_controls(struct Camera*);
void dock_controls(GtkWidget*, struct Camera*);
void closedialog(GtkWidget *widget, GtkWidget *dialog);
